/*********************************************************************************************************
**--------------File Info---------------------------------------------------------------------------------
** File name:           IRQ_timer.c
** Last modified Date:  2014-09-25
** Last Version:        V1.00
** Descriptions:        functions to manage T0 and T1 interrupts
** Correlated files:    timer.h
**--------------------------------------------------------------------------------------------------------
*********************************************************************************************************/
#include "lpc17xx.h"
#include "timer.h"
#include "../led/led.h"
#include "../button_EXINT/button.h"

uint16_t SinTable[45] =                                 
{ 2, 4, 7, 9, 11, 13, 15, 17, 19, 21, 22, 24, 25, 27, 28, 29, 30, 30, 31, 32, 32, 32, 32
 , 32, 32, 31, 30, 30, 29, 28, 27, 25, 24, 22, 21, 19, 17, 15, 13, 11, 9, 7, 5, 2, 0
};

volatile int volume = 5;
volatile int timerStatusVal = 0;
volatile int ssound = 0;

/******************************************************************************
** Function name:		Timer0_IRQHandler
**
** Descriptions:		Timer/Counter 0 interrupt handler
**
** parameters:			None
** Returned value:		None
**
******************************************************************************/

void TIMER0_IRQHandler (void)
{
	static int ticks=0;
	/* DAC management */	
	if(ssound == 1){
		LPC_DAC->DACR = SinTable[ticks]*volume<<6;
	}
	ticks++;
	if(ticks==45) ticks=0;

	
  LPC_TIM0->IR = 1;			/* clear interrupt flag */
  return;
}


/******************************************************************************
** Function name:		Timer1_IRQHandler
**
** Descriptions:		Timer/Counter 1 interrupt handler
**
** parameters:			None
** Returned value:		None
**
******************************************************************************/
void TIMER1_IRQHandler (void)
{
	timerStatusVal = 0; //use to know if the timer is still running
  LPC_TIM1->IR = 1;			/* clear interrupt flag */
  return;
}


void setSpeakerSound(int nSound){
	if(nSound == 1){
		ssound = 1;
	}else
		ssound = 0;
}


void setTimerStart(){
	timerStatusVal = 1;
}

int timerStatus(void){
	return timerStatusVal;
}





/******************************************************************************
**                            End Of File
******************************************************************************/
